package models

import (
	"rdluck_tools/orm"
	"rdluck_tools/paging"
	"time"
)

type Activity struct {
	ActivityTypeId   int    `description:"活动类型id"`
	ActivityTypeName string `description:"活动名称"`
	TemplateP        string `description:"活动模板，带P标签"`
	Template         string `description:"活动模板"`
	ShowType         string `description:"人数限制类型，1不展示限制，2可选限制，3强制限制"`
}
type ActivityIdRep struct {
	ActivityId int `description:"活动id"`
}

type ActivitySingnupRep struct {
	ActivityId int `description:"活动id"`
	SignupType int `description:"报名方式，1预约外呼，2我要报名"`
}

type ActivityCcustomerType struct {
	CustomerTypeId int    `description:"活动类型id"`
	CustomerName   string `description:"活动名称"`
}

type ActivityCcustomerTypeList struct {
	List []*ActivityCcustomerType
}

//列表
func GetActivityCcustomerTypeList() (items []*ActivityCcustomerType, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_customer_type ORDER BY sort DESC`
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

//活动添加、修改入参
type ActivityRep struct {
	ActivityTypeId    int    `description:"活动类型id"`
	ChartPermissionId int    `description:"行业id"`
	Body              string `description:"内容"`
	LimitPeopleNum    int    `description:"限制的人数数量"`
	CustomerTypeIds   string `description:"活动可见的客户类型，多个ID用 , 隔开"`
	ActivityId        int    `description:"活动ID 等于0新增活动，大于0修改活动"`
	DoType            int    `description:"操作类型 0，保存 、1，发布"`
}

//活动详情
type ActivityDetail struct {
	ActivityId              int    `orm:"column(activity_id);pk";description:"活动ID "`
	ActivityTypeId          int    `description:"活动类型id"`
	ActivityTypeName        string `description:"活动类型名称"`
	ChartPermissionId       int    `description:"行业id"`
	ChartPermissionName     string `description:"行业名称"`
	Body                    string `description:"内容"`
	CreateTime              string `description:"创建时间"`
	IsLimitPeople           int    `description:"是否限制人数 1是，0否"`
	LimitPeopleNum          int    `description:"限制的人数数量"`
	LastUpdatedTime         string `description:"更新时间"`
	ActivityTime            string `description:"活动时间"`
	ActivityTimeText        string `description:"活动时间带文字"`
	DistinguishedGuest      string `description:"嘉宾"`
	Host                    string `description:"主持人"`
	Speaker                 string `description:"主讲人"`
	MainlandTell            string `description:"大陆拨入号"`
	HongKongTell            string `description:"香港拨入号"`
	TaiwanTell              string `description:"台湾拨入号"`
	AmericaTell             string `description:"美国拨入号"`
	ParticipationCode       string `description:"参会密码"`
	Theme                   string `description:"主题"`
	Expert                  string `description:"专家"`
	ActivityName            string `description:"活动名称"`
	OnlineParticipation     string `description:"网络参会"`
	ReportLink              string `description:"报告链接"`
	City                    string `description:"城市"`
	Address                 string `description:"活动地址"`
	Highlights              string `description:"活动亮点"`
	Remarks                 string `description:"备注"`
	ShowType                string `description:"人数限制类型，1不展示限制，2可选限制，3强制限制"`
	IsSignup                int    `description:"是否已报名 1是 ，0 否"`
	SignupNum               int    `description:"已报名人数"`
	SignupType              int    `description:"报名方式，1预约外呼，2我要报名"`
	ActiveState             string `description:"活动进行状态 未开始：1、进行中2、已结束3"`
	IsCancelMeetingReminder int    `description:"是否取消会议提醒 1展示取消会议提醒 ，0展示会议提醒"`
}

type CygxActivityResp struct {
	HaqveJurisdiction bool   `description:"是否有权限"`
	OperationMode     string `description:"操作方式 Apply:立即申请、Call:拨号 为空则为有权限"`
	HasPermission     int    `description:"操作方式，1:有该行业权限,正常展示，2：无该行业权限，3：潜在客户，未提交过申请，4：潜在客户,已提交过申请"`
	PopupMsg          string `description:"权限弹窗信息"`
	SellerMobile      string `description:"销售电话"`
	Detail            *ActivityDetail
}

//通过纪要ID获取活动详情
func GetAddActivityInfoById(ActivityId int) (item *ActivityDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_activity  WHERE activity_id=? AND publish_status = 1 `
	err = o.Raw(sql, ActivityId).QueryRow(&item)
	return
}

//通过纪要ID获取活动详情
func GetAddActivityInfoByIdShow(uid, ActivityId int) (item *ActivityDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT *,( SELECT COUNT( 1 ) FROM cygx_activity_signup AS s WHERE s.activity_id = a.activity_id AND s.user_id = ?   AND s.is_cancel = 0) AS is_signup,
			( SELECT COUNT( DISTINCT user_id ) FROM cygx_activity_signup AS s WHERE s.activity_id = a.activity_id  AND s.is_cancel = 0 ) AS signup_num,
			( SELECT COUNT( 1 ) FROM cygx_activity_meeting_reminder AS m WHERE m.activity_id = a.activity_id AND m.user_id = ?  AND m.is_cancel = 0) AS is_cancel_meeting_reminder
			FROM cygx_activity AS a  WHERE activity_id=? AND publish_status = 1 `
	err = o.Raw(sql, uid, uid, ActivityId).QueryRow(&item)
	return
}

//活动详情
type CygxActivityList struct {
	ActivityId              int    `orm:"column(activity_id);pk";description:"活动ID 等于0新增活动，大于0修改活动"`
	ActivityTypeId          int    `description:"活动类型id"`
	ActivityName            string `description:"活动名称"`
	ActivityTypeName        string `description:"活动类型名称"`
	Speaker                 string `description:"主讲人"`
	SignupType              int    `description:"报名方式，1预约外呼，2我要报名"`
	ChartPermissionId       int    `description:"行业id"`
	ChartPermissionName     string `description:"行业名称"`
	IsLimitPeople           int    `description:"是否限制人数 1是，0否"`
	LimitPeopleNum          int    `description:"限制的人数数量"`
	ActivityTime            string `description:"活动时间"`
	ActivityTimeText        string `description:"活动时间带文字"`
	City                    string `description:"城市"`
	DistinguishedGuest      string `description:"嘉宾"`
	Expert                  string `description:"专家"`
	IsSignup                int    `description:"是否已报名 1是 ，0 否"`
	SignupNum               int    `description:"已报名人数"`
	ActiveState             string `description:"活动进行状态 未开始：1、进行中2、已结束3"`
	IsCancelMeetingReminder int    `description:"是否取消会议提醒 1展示取消会议提醒 ，0展示会议提醒"`
	IsBrackets              int    `description:"是否有方括号 1是 ，0 否"`
}

type GetCygxActivityListRep struct {
	Paging *paging.PagingItem `description:"分页数据"`
	List   []*CygxActivityList
}

//列表
func GetActivityListAll(condition string, pars []interface{}, uid, startSize, pageSize int) (items []*CygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT * ,
		( SELECT COUNT( 1 ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id AND s.user_id = ?   AND s.is_cancel = 0) AS is_signup,
		( SELECT COUNT( DISTINCT user_id ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id   AND s.is_cancel = 0) AS signup_num,
		( SELECT COUNT( 1 ) FROM cygx_activity_meeting_reminder AS m WHERE m.activity_id = art.activity_id AND m.user_id = ?  AND m.is_cancel = 0 ) AS is_cancel_meeting_reminder
		FROM cygx_activity as art WHERE 1= 1 `
	if condition != "" {
		sql += condition
	}
	sql += ` LIMIT ?,?`
	_, err = o.Raw(sql, pars, uid, uid, startSize, pageSize).QueryRows(&items)
	return
}

//获取数量
func GetActivityCount(condition string, pars []interface{}) (count int, err error) {
	sqlCount := ` SELECT COUNT(1) AS count  FROM cygx_activity as art WHERE 1= 1  `
	if condition != "" {
		sqlCount += condition
	}
	o := orm.NewOrm()
	err = o.Raw(sqlCount, pars).QueryRow(&count)
	return
}

//获取我的日程数量
func GetScheduleCount(uid int) (count int, err error) {
	o := orm.NewOrm()
	//sqlCount := ` SELECT COUNT( 1 ) AS count  FROM cygx_activity AS art  INNER JOIN cygx_activity_signup as s ON s.activity_id = art.activity_id
	//				WHERE  	s.user_id = ?  AND s.is_cancel = 0 `
	//if condition != "" {
	//	sqlCount += condition
	//}
	sqlCount := ` SELECT COUNT( 1 ) AS count  FROM cygx_my_schedule WHERE user_id = ?`
	err = o.Raw(sqlCount, uid).QueryRow(&count)
	return
}

//我的日程列表
func GetScheduleList(condition string, pars []interface{}, uid, startSize, pageSize int) (items []*CygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT art.*,( SELECT COUNT( 1 ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id AND s.user_id = ? AND s.is_cancel = 0 ) AS is_signup,
                     ( SELECT COUNT( DISTINCT user_id ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id AND  s.is_cancel = 0  AND s.fail_type = 0 ) AS signup_num ,
					 ( SELECT COUNT( 1 ) FROM cygx_activity_meeting_reminder AS m WHERE m.activity_id = art.activity_id AND m.user_id = ? ) AS is_cancel_meeting_reminder
            FROM cygx_activity AS art
			INNER JOIN cygx_my_schedule as my ON my.activity_id = art.activity_id 
            WHERE 1=1 AND my.user_id = ? `
	if condition != "" {
		sql += condition
	}
	sql += ` ORDER BY art.active_state,art.activity_time DESC  LIMIT ?,?`
	_, err = o.Raw(sql, pars, uid, uid, uid, startSize, pageSize).QueryRows(&items)
	return
}

//获取数量
func GetActivityCountById(activityId int) (count int, err error) {
	o := orm.NewOrm()
	sqlCount := `SELECT COUNT(1) AS count  FROM cygx_activity WHERE activity_id = ?`
	err = o.Raw(sqlCount, activityId).QueryRow(&count)
	return
}

//删除数据
func DeleteActivity(activityId int) (err error) {
	o := orm.NewOrm()
	sql := ` DELETE FROM cygx_activity WHERE activity_id = ?`
	_, err = o.Raw(sql, activityId).Exec()
	return
}

//修改活动状态至进行中
func UpdateActivitySattusToHaveInHand() (err error) {
	o := orm.NewOrm()
	resultTime_30 := time.Now().Add(-time.Minute * 30).Format("2006-01-02 15:04:05")
	resultTime_60 := time.Now().Add(-time.Minute * 60).Format("2006-01-02 15:04:05")
	var sqlOr string
	var condition string
	condition += ` AND activity_time < NOW()`
	sqlOr = condition
	condition += ` AND (activity_type_id IN ( 1, 2, 3 ) AND  activity_time > ` + "'" + resultTime_30 + "'" + ")"
	condition += ` OR(activity_type_id IN ( 4, 5, 6 ) AND  activity_time > ` + "'" + resultTime_60 + "'" + sqlOr + ")"
	msql := " UPDATE cygx_activity SET active_state = 2 WHERE 1 = 1 " + condition
	_, err = o.Raw(msql).Exec()
	return
}

//修改活动状态至已结束
func UpdateActivitySattusToComplete() (err error) {
	o := orm.NewOrm()
	resultTime_30 := time.Now().Add(-time.Minute * 30).Format("2006-01-02 15:04:05")
	resultTime_60 := time.Now().Add(-time.Minute * 60).Format("2006-01-02 15:04:05")
	//var sqlOr string
	var condition string
	//condition += ` AND activity_time < NOW()`
	//sqlOr = condition
	condition += ` AND (activity_type_id IN ( 1, 2, 3 ) AND  activity_time < ` + "'" + resultTime_30 + "'" + ")"
	condition += ` OR(activity_type_id IN ( 4, 5, 6 ) AND  activity_time < ` + "'" + resultTime_60 + "'" + ")"
	msql := " UPDATE cygx_activity SET active_state = 3 WHERE 1 = 1 " + condition
	_, err = o.Raw(msql).Exec()
	return
}
